@@ -9,12 +9,13 @@ class Roles(ApiResource):
             'branch': self.branch,
         })
 
-    def upsert(self, role_id, permissions, parent_roles=None, org_id='*'):
+    def upsert(self, role_id, permissions, owners={}, parent_roles=None, org_id='*'):
         parents = parent_roles or []
 
         return self.dispatch('/v1/roles', HttpMethods.POST, {
             'id': role_id,
             'permissions': permissions,
+            'owners': owners,
             'parent_roles': parents,
             'org_id': org_id,
             'branch': self.branch,
